Name:      percolator
Summary:   Software for postprocessing of shotgun proteomics data
Version:   2.10.1
Release:   1%{?dist}

## Code under src/ (except RAMP and Fido sub-directories) is licensed under a ASL 2.0 license.
## Code under src/Fido under MIT license.
## Code under src/MSToolkit under BSD license.
## Code under src/converters/MSToolkit/RAMP is licensed under a LGPLv2+ license.
License:   ASL 2.0 and MIT and BSD and LGPLv2+
URL:       http://per-colator.com/
Source0:   https://github.com/percolator/percolator/tarball/master#/percolator-percolator-rel-2-10-1-gd92d600.tar.gz
## Example files for testing
## https://github.com/percolator/percolator/wiki/Example
Source1:   http://noble.gs.washington.edu/proj/percolator/data/yeast-01.sqt.tar.gz
Source2:   %{name}-RAMP_license_lgpl-2.1.txt

%if 0%{?rhel}
BuildRequires: cmake28
BuildRequires: boost148-static, boost148-devel
BuildRequires: pkgconfig(tokyocabinet)
BuildRequires: pkgconfig(xerces-c)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: xsd, zlib-devel, bzip2-devel
%else
BuildRequires: cmake, libxml-devel
BuildRequires: boost-static, boost-devel
BuildRequires: pkgconfig(tokyocabinet)
BuildRequires: pkgconfig(xerces-c)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: xsd, zlib-devel, bzip2-devel
%endif

Requires: %{name}-data = %{version}-%{release}

%description
The first step in analyzing an mass spectrometry assay is to match
the harvested spectra against a target database 
using database search engines such as Sequest and Mascot,
a process that renders list of peptide-spectrum matches.
However, it is not trivial to assess the accuracy
of these identifications.

Percolator uses a semi-supervised machine learning to 
discriminate correct from incorrect peptide-spectrum matches,
and calculates accurate statistics such as q-value (FDR)
and posterior error probabilities.

%package data
Summary: percolator data files
BuildArch: noarch
Requires: xml-common

%description data
This package contains XSD data files of %{name} and
models of elude tool.

%package static
Summary: percolator static libraries

%description static
This package contains static libraries of %{name}.

%prep
%setup -q -n percolator-percolator-d92d600
tar -xvf %{SOURCE1}

## Remove spurious executable permissions
for i in `find . -perm /755 -type f \( -name "*.cpp" -o -name "*.h" -o -name "*.*xx" -o -name "*.txt" \)`; do
 chmod a-x $i
done

## Rename additional readme files
chmod a-x src/converters/MSToolkit/RAMP/README
mv src/converters/MSToolkit/RAMP/README src/converters/MSToolkit/RAMP/RAMP-README
mv src/converters/MSToolkit/RAMP/Readme.Mike.txt src/converters/MSToolkit/RAMP/RAMP-Readme.Mike.txt

## Included LGPLv2+ license
cp -p %{SOURCE2} RAMP_license_lgpl-2.1.txt

## Set 'qvality' destination directory
sed -e 's|./bin|bin|g' -i src/qvality/CMakeLists.txt

## Set 'elude models' destination directory
sed -e 's|${ELUDE_MODELS_PATH}..|${ELUDE_MODELS_PATH}|g' -i src/elude_tool/CMakeLists.txt
sed -e 's|${CMAKE_INSTALL_PREFIX}/share/elude/models/|${CMAKE_INSTALL_PREFIX}/share/elude|g' -i src/elude_tool/CMakeLists.txt

%build

mkdir -p percolator && pushd percolator
%if 0%{?rhel}
 %cmake28 \
%else
%cmake -Wno-dev \
%endif
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE -DXML_SUPPORT:BOOL=ON \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING=" -I../src -I%{_includedir}/xsd/cxx/tree" \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
%if 0%{?rhel}
 -DBOOST_LIBRARYDIR=%{_libdir}/boost148 \
 -DXML_SUPPORT:BOOL=OFF \
%endif
 -DTARGET_ARCH=%{_arch} ..

### XSD files ran maually
### In Fedora 'xsd' executable is 'xsdcxx'
cd src
xsdcxx cxx-tree --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_in/13=percolatorInNs ../../src/xml/percolator_in.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_out/15=percolatorOutNs ../../src/xml/percolator_out.xsd
cd ..
###

make %{?_smp_mflags}
popd

mkdir -p fido && pushd fido
%if 0%{?rhel}
 %cmake28 \
%else
%cmake -Wno-dev \
%endif
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING=" -I../src" \
 -DTokyoCabinet_INCLUDE_DIR=%{_includedir} \
 -DTokyoCabinet_LIBRARY=%{_libdir}/libtokyocabinet.so \
%if 0%{?rhel}
 -DBOOST_LIBRARYDIR=%{_libdir}/boost148 \
 -DXML_SUPPORT:BOOL=OFF \
%endif
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DTARGET_ARCH=%{_arch} ../src/fido
make %{?_smp_mflags}
popd

mkdir -p converters && pushd converters
%if 0%{?rhel}
 %cmake28 \
%else
%cmake -Wno-dev \
%endif
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING=" -I../src -I%{_includedir}/xsd/cxx/tree" \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DPERCOLATOR-CONVERTERS_BINARY_DIR:STATIC=converters \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
 -DTokyoCabinet_INCLUDE_DIR=%{_includedir} \
 -DTokyoCabinet_LIBRARY=%{_libdir}/libtokyocabinet.so \
 -DSERIALIZE="TokyoCabinet" \
%if 0%{?rhel}
 -DBoost_FILESYSTEM_LIBRARY_RELEASE:FILEPATH=%{_libdir}/boost148/libboost_filesystem.so \
 -DBoost_SERIALIZATION_LIBRARY_RELEASE:FILEPATH=%{_libdir}/boost148/libboost_serialization.so \
 -DBoost_SYSTEM_LIBRARY_RELEASE:FILEPATH=%{_libdir}/boost148/libboost_system.so \
 -DBoost_INCLUDE_DIR:PATH=%{_includedir}/boost148 \
 -DBoost_LIBRARY_DIR:PATH=%{_libdir}/boost148 \
 -DXML_SUPPORT:BOOL=OFF \
%endif
 -DTARGET_ARCH=%{_arch} ../src/converters

### XSD files ran maually
### In Fedora 'xsd' executable is 'xsdcxx'
xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_in/13=percolatorInNs ../src/xml/percolator_in.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://per-colator.com/percolator_out/15=percolatorOutNs ../src/xml/percolator_out.xsd
##
xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://psidev.info/psi/pi/mzIdentML/1.1=mzIdentML_ns ../src/xml/mzIdentML1.1.0.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://www.bioml.com/gaml/=gaml_tandem_ns ../src/xml/gaml_tandem1.0.xsd

xsdcxx cxx-tree --generate-serialization --generate-insertion XDR --generate-extraction XDR --root-element-all \
 --namespace-map http://www.thegpm.org/TANDEM/2011.12.01.1=tandem_ns --namespace-map =tandem_ns \
 --namespace-map http://www.bioml.com/gaml/=gaml_tandem_ns ../src/xml/tandem2011.12.01.1.xsd
###

make %{?_smp_mflags}
popd

mkdir -p elude && pushd elude
%if 0%{?rhel}
 %cmake28 \
%else
%cmake -Wno-dev \
%endif
 -DCMAKE_COLOR_MAKEFILE:BOOL=ON \
 -DCMAKE_VERBOSE_MAKEFILE=TRUE \
 -DCMAKE_CXX_FLAGS_RELEASE:STRING=" -I../src" \
 -DCMAKE_BUILD_TYPE:STRING=Release \
 -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES -DCMAKE_SKIP_RPATH:BOOL=YES \
%if 0%{?rhel}
 -DBOOST_LIBRARYDIR=%{_libdir}/boost148 \
 -DXML_SUPPORT:BOOL=OFF \
%endif
 -DTARGET_ARCH=%{_arch} ../src/elude_tool
make %{?_smp_mflags}
popd

%install
make install DESTDIR=%{buildroot} -C percolator
make install DESTDIR=%{buildroot} -C converters
make install DESTDIR=%{buildroot} -C elude

## Install static libraries
mkdir -p %{buildroot}%{_libdir}/percolator
for i in `find . -type f \( -name "*.a" \)`; do
 install -pm 755 $i %{buildroot}%{_libdir}/percolator
done

%check
mkdir -p test && cd test
../converters/sqt2pin -o pin.tab ../yeast-01.sqt ../yeast-01.shuffled.sqt
../percolator/src/percolator -X pout.xml pin.tab > yeast-01.psms

%files
# ASL 2.0 and MIT
%{_bindir}/percolator
# ASL 2.0 and LGPLv2+ and MIT and BSD
%{_bindir}/sqt2pin
%{_bindir}/qvality
%{_bindir}/elude
%{_bindir}/tandem2pin
%{_bindir}/msgf2pin

%files data
%doc ReadMe.txt
%doc src/converters/MSToolkit/RAMP/RAMP-*
%if 0%{?rhel} < 7
%doc license.txt
%doc RAMP_license_lgpl-2.1.txt
%else
%license license.txt
%license RAMP_license_lgpl-2.1.txt
%endif
%{_datadir}/elude/
%{_datadir}/percolator/
%{_datadir}/xml/percolator/

%files static
%doc ReadMe.txt
%doc src/converters/MSToolkit/RAMP/RAMP-*
%if 0%{?rhel} < 7
%doc license.txt
%doc RAMP_license_lgpl-2.1.txt
%else
%license license.txt
%license RAMP_license_lgpl-2.1.txt
%endif
%{_libdir}/percolator/

%changelog
* Tue Jul 07 2015 Antonio Trande <sagitter@fedoraproject.org> 2.10.1-1
- Update to 2.10.1
- Made a -static sub-package

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.09.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 25 2015 Antonio Trande <sagitter@fedoraproject.org> 2.09.0-4
- -data sub-package now requires xml-common

* Sun May 24 2015 Antonio Trande <sagitter@fedoraproject.org> 2.09.0-3
- The licensing breakdown is documented
- Removed spurious executable permissions
- /usr/share/xml is co-owned

* Sat May 23 2015 Antonio Trande <sagitter@fedoraproject.org> 2.09.0-2
- Added LGPLv2+ license of RAMP parser
- Made a data sub-package

* Fri May 22 2015 Antonio Trande <sagitter@fedoraproject.org> 2.09.0-1
- First package
